==> clean_android_design-0.0.129.tar.gz: lib/clean_android_design.dart <==
library clean_android_design;

export 'package:clean_android_design/src/dialog/default_dialog.dart';
export 'package:clean_android_design/src/dialog/default_dialog_button_widget.dart';
export 'package:clean_android_design/src/dialog/save_or_abort_dialog.dart';
export 'package:clean_android_design/src/dialog/datetime_picker_dialog.dart';

export 'package:clean_android_design/src/fields/default_field_widget.dart';
export 'package:clean_android_design/src/fields/text_field_widget.dart';
export 'package:clean_android_design/src/fields/datetime_field_widget.dart';
export 'package:clean_android_design/src/fields/selectable_list_field_widget.dart';

export 'package:clean_android_design/src/navigator/split_navigator.dart';
export 'package:clean_android_design/src/navigator/locked_navigator_widget.dart';

export 'package:clean_android_design/src/settings/clean_android_design_style.dart';
export 'package:clean_android_design/src/settings/settings.dart';

export 'package:clean_android_design/src/help/help_side_widget.dart';
export 'package:clean_android_design/src/help/i_help_widget.dart';

export 'package:clean_android_design/src/utils/item_section_widget.dart';
export 'package:clean_android_design/src/utils/button_widget.dart';
export 'package:clean_android_design/src/utils/description_text.dart';
export 'package:clean_android_design/src/utils/highlight_builder.dart';
export 'package:clean_android_design/src/utils/key_collection.dart';
export 'package:clean_android_design/src/utils/loading_widget.dart';
export 'package:clean_android_design/src/utils/validation/validator.dart';
export 'package:clean_android_design/src/utils/validation/field_validation.dart';
export 'package:clean_android_design/src/utils/validation/validation.dart';
export 'package:clean_android_design/src/utils/force_update_key.dart';
export 'package:clean_android_design/src/utils/adaptive_text.dart';

export 'package:clean_android_design/src/services/database_service_interface.dart';
export 'package:clean_android_design/src/services/models_interfaces.dart';
export 'package:clean_android_design/src/services/snackbar_controller.dart';

export 'package:clean_android_design/src/structure/default_scaffold_widget.dart';
export 'package:clean_android_design/src/structure/default_update_scaffold_widget.dart';
export 'package:clean_android_design/src/structure/icon_scaffold_menu_button_widget.dart';
export 'package:clean_android_design/src/structure/menu_widget.dart';
export 'package:clean_android_design/src/structure/navigator_widget.dart';
export 'package:clean_android_design/src/structure/scaffold_page_widget.dart';
export 'package:clean_android_design/src/structure/simple_scaffold_menu_button_widget.dart';
export 'package:clean_android_design/src/structure/tab_scaffold_widget.dart';

export 'package:clean_android_design/src/structure/list/default_list_item.dart';
export 'package:clean_android_design/src/structure/list/list_scaffold_widget.dart';
export 'package:clean_android_design/src/structure/list/scroll_bar_widget.dart';

==> clean_android_design-0.0.132.tar.gz: lib/clean_android_design.dart <==
library clean_android_design;

export 'package:clean_android_design/src/dialog/default_dialog.dart';
export 'package:clean_android_design/src/dialog/default_dialog_button_widget.dart';
export 'package:clean_android_design/src/dialog/save_or_abort_dialog.dart';
export 'package:clean_android_design/src/dialog/datetime_picker_dialog.dart';

export 'package:clean_android_design/src/fields/default_field_widget.dart';
export 'package:clean_android_design/src/fields/text_field_widget.dart';
export 'package:clean_android_design/src/fields/datetime_field_widget.dart';
export 'package:clean_android_design/src/fields/selectable_list_field_widget.dart';

export 'package:clean_android_design/src/navigator/split_navigator.dart';
export 'package:clean_android_design/src/navigator/locked_navigator_widget.dart';

export 'package:clean_android_design/src/settings/clean_android_design_style.dart';
export 'package:clean_android_design/src/settings/settings.dart';

export 'package:clean_android_design/src/help/help_side_widget.dart';
export 'package:clean_android_design/src/help/i_help_widget.dart';

export 'package:clean_android_design/src/utils/item_section_widget.dart';
export 'package:clean_android_design/src/utils/button_widget.dart';
export 'package:clean_android_design/src/utils/description_text.dart';
export 'package:clean_android_design/src/utils/highlight_builder.dart';
export 'package:clean_android_design/src/utils/key_collection.dart';
export 'package:clean_android_design/src/utils/loading_widget.dart';
export 'package:clean_android_design/src/utils/validation/validator.dart';
export 'package:clean_android_design/src/utils/validation/field_validation.dart';
export 'package:clean_android_design/src/utils/validation/validation.dart';
export 'package:clean_android_design/src/utils/force_update_key.dart';
export 'package:clean_android_design/src/utils/adaptive_text.dart';

export 'package:clean_android_design/src/services/update_scaffold_widget_service_interface.dart';
export 'package:clean_android_design/src/services/models_interfaces.dart';
export 'package:clean_android_design/src/services/snackbar_controller.dart';

export 'package:clean_android_design/src/structure/default_scaffold_widget.dart';
export 'package:clean_android_design/src/structure/default_update_scaffold_widget.dart';
export 'package:clean_android_design/src/structure/icon_scaffold_menu_button_widget.dart';
export 'package:clean_android_design/src/structure/menu_widget.dart';
export 'package:clean_android_design/src/structure/navigator_widget.dart';
export 'package:clean_android_design/src/structure/scaffold_page_widget.dart';
export 'package:clean_android_design/src/structure/simple_scaffold_menu_button_widget.dart';
export 'package:clean_android_design/src/structure/tab_scaffold_widget.dart';

export 'package:clean_android_design/src/structure/list/default_list_item.dart';
export 'package:clean_android_design/src/structure/list/list_scaffold_widget.dart';
export 'package:clean_android_design/src/structure/list/scroll_bar_widget.dart';
